"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  AuthenticationProvider: () => AuthenticationProvider_default,
  useAccount: () => useUserAccount_default,
  useAuthenticated: () => useAuthenticated_default,
  useAuthentication: () => useMsalAuthentication_default
});
module.exports = __toCommonJS(src_exports);

// src/AuthenticationProvider.tsx
var import_react4 = __toESM(require("react"));
var import_msal_browser3 = require("@azure/msal-browser");
var import_msal_react3 = require("@azure/msal-react");

// src/hooks/useConfiguration.ts
var import_react = require("react");
var import_msal_browser = require("@azure/msal-browser");

// src/configs/index.ts
var environmentConfig = () => ({
  clientId: process.env["VITE_MSAL_CLIENT_ID"],
  authority: process.env["VITE_MSAL_AUTHORITY"],
  loginRedirectUri: process.env["VITE_MSAL_REDIRECT_URL"],
  logoutRedirectUri: process.env["VITE_MSAL_LOGOUT_REDIRECT_URL"],
  scopes: process.env["VITE_MSAL_SCOPES"],
  cacheLoc: process.env["VITE_MSAL_CACHE_LOCATION"],
  tokenInterval: process.env["VITE_MSAL_TOKEN_INTERVAL"],
  tokenThreshold: process.env["VITE_MSAL_TOKEN_REFRESH_THRESHOLD"]
});
var Constants = {
  SPLIT_COMMA: ",",
  TOKEN_INTERVAL: 36e5,
  TOKEN_THRESHOLD: 300,
  SCOPES: ["User.Read"]
};
var ConstantsMessage = {
  MSG_ENV: "Missing environment configuration",
  MSG_CLIENT_ID: "Missing clientId",
  MSG_AUTH_URL: "Missing authority url",
  MSG_REDIRECT_URL: "Missing redirect url"
};

// src/hooks/useConfiguration.ts
var useConfiguration = (authConfig) => {
  const [config, setConfig] = (0, import_react.useState)();
  const [options, setOptions] = (0, import_react.useState)();
  (0, import_react.useEffect)(() => {
    if (authConfig != null && authConfig.option) {
      setOptions(authConfig.option);
    }
    const clientInstance = authConfig && authConfig.instance ? authConfig.instance : defaultInstance();
    const msalInstance = new import_msal_browser.PublicClientApplication(clientInstance);
    if (msalInstance) {
      setConfig(msalInstance);
    }
  }, [authConfig]);
  const defaultInstance = () => {
    const env = environmentConfig();
    if (!env)
      throw new Error(ConstantsMessage.MSG_ENV);
    let interval = Constants.TOKEN_INTERVAL;
    let threshold = Constants.TOKEN_THRESHOLD;
    let cacheLoc = import_msal_browser.BrowserCacheLocation.LocalStorage;
    if (!env.clientId) {
      throw new Error(ConstantsMessage.MSG_CLIENT_ID);
    }
    if (!env.authority) {
      throw new Error(ConstantsMessage.MSG_AUTH_URL);
    }
    if (!env.loginRedirectUri) {
      throw new Error(ConstantsMessage.MSG_REDIRECT_URL);
    }
    if (env.tokenInterval) {
      interval = parseInt(env.tokenInterval);
    }
    if (env.tokenThreshold) {
      threshold = parseInt(env.tokenInterval);
    }
    if (env.cacheLoc) {
      cacheLoc = import_msal_browser.BrowserCacheLocation[env.cacheLoc];
    }
    setOptions({
      scopes: env.scopes?.split(Constants.SPLIT_COMMA),
      tokenInterval: interval,
      tokenThreshold: threshold
    });
    const defaultConfig = {
      auth: {
        clientId: env.clientId,
        authority: env.authority,
        redirectUri: env.loginRedirectUri,
        postLogoutRedirectUri: env.logoutRedirectUri,
        navigateToLoginRequestUrl: false
      },
      cache: {
        cacheLocation: cacheLoc,
        storeAuthStateInCookie: true
      },
      system: {
        tokenRenewalOffsetSeconds: Constants.TOKEN_THRESHOLD
      }
    };
    return defaultConfig;
  };
  return { config, option: options };
};
var useConfiguration_default = useConfiguration;

// src/components/AuthenticationSuccess.tsx
var import_react3 = __toESM(require("react"));
var import_msal_react2 = require("@azure/msal-react");

// src/hooks/useUserAccount.ts
var import_msal_react = require("@azure/msal-react");
var import_msal_browser2 = require("@azure/msal-browser");
var import_jwt_decode = require("jwt-decode");
var import_react_framework = require("react.framework.userclaim");
var import_react2 = require("react");
var useUserAccount = () => {
  let requestScope = Constants.SCOPES;
  const tokenRef = (0, import_react2.useRef)("");
  const isAuthenticated = (0, import_msal_react.useIsAuthenticated)();
  const { instance, accounts } = (0, import_msal_react.useMsal)();
  const { setUserToken, getTokenInfo } = (0, import_react_framework.useUserTokenService)();
  const { setUserClaims } = (0, import_react_framework.useUserClaimService)();
  const { setUserInfo } = (0, import_react_framework.useUserService)();
  const getUserToken = async () => {
    let tokenInfo;
    let i = 0;
    do {
      tokenInfo = getTokenInfo();
      if (!tokenInfo || tokenInfo === null) {
        await setTokenToStore();
      }
      if (i == 2)
        break;
      i++;
    } while (!tokenInfo);
    return tokenRef.current;
  };
  const setAcquireTokenToStore = async (scopes) => {
    if (isAuthenticated) {
      if (scopes && scopes.length > 0) {
        requestScope = [...requestScope, ...scopes];
      }
      const tokenInfo = getTokenInfo();
      if (!tokenInfo || tokenInfo === null) {
        setTokenToStore();
      }
    }
  };
  const setTokenToStore = async () => {
    const accountInfo = await getAcquireTokenSilent();
    if (accountInfo) {
      setUserAccountInfoToStore(accountInfo);
    }
  };
  const getAcquireTokenSilent = async () => {
    const authRequest = {
      account: accounts[0],
      scopes: requestScope
    };
    try {
      const response = await instance.acquireTokenSilent(authRequest);
      return response;
    } catch (err) {
      if (err instanceof import_msal_browser2.InteractionRequiredAuthError) {
        await instance.acquireTokenRedirect(authRequest);
      }
    }
  };
  const setUserAccountInfoToStore = (accountInfo) => {
    if (accountInfo) {
      const userTokenExtent = accountInfo;
      const userToken = {
        tokenId: userTokenExtent.tokenId,
        refreshToken: userTokenExtent.accessToken,
        tokenExpirationDate: userTokenExtent.expiresOn,
        userToken: userTokenExtent.accessToken
      };
      setUserToken(userToken);
      if (userToken.userToken) {
        const decodeToken = (0, import_jwt_decode.jwtDecode)(userToken.userToken);
        if (decodeToken) {
          const user = {
            id: 1,
            email: decodeToken.upn,
            firstname: decodeToken.family_name,
            lastName: decodeToken.given_name,
            name: decodeToken.name
          };
          setUserInfo(user);
        }
      }
      const userAccountExtent = accountInfo.account;
      if (userAccountExtent) {
        const userClaims = [
          { key: "name", value: userAccountExtent.name ?? "" },
          { key: "username", value: userAccountExtent.username ?? "" }
        ];
        setUserClaims(userClaims);
      }
      tokenRef.current = userTokenExtent.accessToken;
    }
  };
  const setUserActiveAccount = async () => {
    const currentAccounts = instance.getAllAccounts();
    if (currentAccounts.length > 0) {
      instance.setActiveAccount(currentAccounts[0]);
    }
  };
  return { getUserToken, setAcquireTokenToStore, setUserActiveAccount };
};
var useUserAccount_default = useUserAccount;

// src/components/AuthenticationSuccess.tsx
var AuthenticationSuccess = ({ children, option }) => {
  const interval = (0, import_react3.useRef)(null);
  const isAuthenticated = (0, import_msal_react2.useIsAuthenticated)();
  const { setAcquireTokenToStore, setUserActiveAccount } = useUserAccount_default();
  const { accounts } = (0, import_msal_react2.useMsal)();
  (0, import_react3.useEffect)(() => {
    if (isAuthenticated) {
      setUserActiveAccount();
      setAcquireTokenToStore(option?.scopes);
      if (option != null) {
        interval.current = setInterval(checkTokenExpiry, option.tokenInterval);
      }
    }
    return () => clearInterval(interval.current);
  }, [isAuthenticated]);
  const checkTokenExpiry = () => {
    if (isAuthenticated) {
      const account = accounts[0];
      const idTokenClaimsExp = account.idTokenClaims?.exp;
      if (idTokenClaimsExp) {
        const currentTime = Math.floor(Date.now() / 1e3);
        const timeUntilExpiry = idTokenClaimsExp - currentTime;
        const tokenThreshold = option?.tokenThreshold ?? 0;
        if (timeUntilExpiry <= tokenThreshold) {
          setAcquireTokenToStore(option?.scopes);
        }
      }
    }
  };
  return /* @__PURE__ */ import_react3.default.createElement(import_react3.default.Fragment, null, children);
};
var AuthenticationSuccess_default = AuthenticationSuccess;

// src/AuthenticationProvider.tsx
var AuthenticationProvider = ({ children, beforeAuthComponent, authConfig }) => {
  const { config, option } = useConfiguration_default(authConfig);
  return config != null ? /* @__PURE__ */ import_react4.default.createElement(import_msal_react3.MsalProvider, { instance: config }, beforeAuthComponent ? /* @__PURE__ */ import_react4.default.createElement(import_react4.default.Fragment, null, /* @__PURE__ */ import_react4.default.createElement(import_msal_react3.UnauthenticatedTemplate, null, beforeAuthComponent), /* @__PURE__ */ import_react4.default.createElement(import_msal_react3.AuthenticatedTemplate, null, /* @__PURE__ */ import_react4.default.createElement(AuthenticationSuccess_default, { option }, children))) : /* @__PURE__ */ import_react4.default.createElement(import_react4.default.Fragment, null, /* @__PURE__ */ import_react4.default.createElement(import_msal_react3.MsalAuthenticationTemplate, { authenticationRequest: { scopes: option?.scopes }, interactionType: import_msal_browser3.InteractionType.Redirect }, /* @__PURE__ */ import_react4.default.createElement(AuthenticationSuccess_default, { option }, children)))) : null;
};
var AuthenticationProvider_default = AuthenticationProvider;

// src/hooks/useMsalAuthentication.ts
var import_msal_react4 = require("@azure/msal-react");
var useMsalAuthentication = () => {
  const { instance } = (0, import_msal_react4.useMsal)();
  const loginRedirect = () => {
    instance.loginRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const loginPopup = () => {
    instance.loginPopup().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutRedirect = () => {
    instance.logoutRedirect().catch((error) => {
      throw new Error(error);
    });
  };
  const logoutPopup = () => {
    instance.logoutPopup({
      account: instance.getActiveAccount()
    }).catch((error) => {
      throw new Error(error);
    });
  };
  return { loginRedirect, loginPopup, logoutRedirect, logoutPopup };
};
var useMsalAuthentication_default = useMsalAuthentication;

// src/hooks/useAuthenticated.ts
var import_msal_react5 = require("@azure/msal-react");
var useAuthenticated = () => {
  const isAuthenticated = (0, import_msal_react5.useIsAuthenticated)();
  return isAuthenticated;
};
var useAuthenticated_default = useAuthenticated;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  AuthenticationProvider,
  useAccount,
  useAuthenticated,
  useAuthentication
});
